CoverExportFormat class

Specify the file format to use when exporting the video cover some common formats such as jpg, png and webp has a default constructor.

If you need another file format you can specify it like

CoverExportFormat('jpeg');
Inheritance

Constructors

CoverExportFormat(String extension, {required String mimeType})
const

Properties

extension → String
Extension of the file without the dot ..
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String
The MIME type of the file format.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

jpg → const CoverExportFormat
png → const CoverExportFormat
webp → const CoverExportFormat