FileFormat class abstract

Implementers

Constructors

FileFormat(String extension, {required String mimeType})
const
FileFormat.fromMimeType(String? mimeType)
factory

Properties

extension → String
Extension of the file without the dot ..
final
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String
The MIME type of the file format.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited